# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cjm-transcription-plugin-system',
                'doc_host': 'https://cj-mills.github.io',
                'git_url': 'https://github.com/cj-mills/cjm-transcription-plugin-system',
                'lib_path': 'cjm_transcription_plugin_system'},
  'syms': { 'cjm_transcription_plugin_system.core': { 'cjm_transcription_plugin_system.core.AudioData': ( 'core.html#audiodata',
                                                                                                          'cjm_transcription_plugin_system/core.py'),
                                                      'cjm_transcription_plugin_system.core.TranscriptionResult': ( 'core.html#transcriptionresult',
                                                                                                                    'cjm_transcription_plugin_system/core.py')},
            'cjm_transcription_plugin_system.plugin_interface': { 'cjm_transcription_plugin_system.plugin_interface.PluginInterface': ( 'plugin_interface.html#plugininterface',
                                                                                                                                        'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.cleanup': ( 'plugin_interface.html#plugininterface.cleanup',
                                                                                                                                                'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.execute': ( 'plugin_interface.html#plugininterface.execute',
                                                                                                                                                'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.get_config_defaults': ( 'plugin_interface.html#plugininterface.get_config_defaults',
                                                                                                                                                            'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.get_config_schema': ( 'plugin_interface.html#plugininterface.get_config_schema',
                                                                                                                                                          'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.get_current_config': ( 'plugin_interface.html#plugininterface.get_current_config',
                                                                                                                                                           'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.initialize': ( 'plugin_interface.html#plugininterface.initialize',
                                                                                                                                                   'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.is_available': ( 'plugin_interface.html#plugininterface.is_available',
                                                                                                                                                     'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.name': ( 'plugin_interface.html#plugininterface.name',
                                                                                                                                             'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.supported_formats': ( 'plugin_interface.html#plugininterface.supported_formats',
                                                                                                                                                          'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.validate_config': ( 'plugin_interface.html#plugininterface.validate_config',
                                                                                                                                                        'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginInterface.version': ( 'plugin_interface.html#plugininterface.version',
                                                                                                                                                'cjm_transcription_plugin_system/plugin_interface.py'),
                                                                  'cjm_transcription_plugin_system.plugin_interface.PluginMeta': ( 'plugin_interface.html#pluginmeta',
                                                                                                                                   'cjm_transcription_plugin_system/plugin_interface.py')},
            'cjm_transcription_plugin_system.plugin_manager': { 'cjm_transcription_plugin_system.plugin_manager.PluginManager': ( 'plugin_manager.html#pluginmanager',
                                                                                                                                  'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.__init__': ( 'plugin_manager.html#pluginmanager.__init__',
                                                                                                                                           'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.disable_plugin': ( 'plugin_manager.html#pluginmanager.disable_plugin',
                                                                                                                                                 'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.discover_plugins': ( 'plugin_manager.html#pluginmanager.discover_plugins',
                                                                                                                                                   'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.enable_plugin': ( 'plugin_manager.html#pluginmanager.enable_plugin',
                                                                                                                                                'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.execute_plugin': ( 'plugin_manager.html#pluginmanager.execute_plugin',
                                                                                                                                                 'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.get_plugin': ( 'plugin_manager.html#pluginmanager.get_plugin',
                                                                                                                                             'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.list_plugins': ( 'plugin_manager.html#pluginmanager.list_plugins',
                                                                                                                                               'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.load_plugin': ( 'plugin_manager.html#pluginmanager.load_plugin',
                                                                                                                                              'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.load_plugin_from_module': ( 'plugin_manager.html#pluginmanager.load_plugin_from_module',
                                                                                                                                                          'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.PluginManager.unload_plugin': ( 'plugin_manager.html#pluginmanager.unload_plugin',
                                                                                                                                                'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.get_all_plugin_schemas': ( 'plugin_manager.html#get_all_plugin_schemas',
                                                                                                                                           'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.get_plugin_config': ( 'plugin_manager.html#get_plugin_config',
                                                                                                                                      'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.get_plugin_config_schema': ( 'plugin_manager.html#get_plugin_config_schema',
                                                                                                                                             'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.reload_plugin': ( 'plugin_manager.html#reload_plugin',
                                                                                                                                  'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.update_plugin_config': ( 'plugin_manager.html#update_plugin_config',
                                                                                                                                         'cjm_transcription_plugin_system/plugin_manager.py'),
                                                                'cjm_transcription_plugin_system.plugin_manager.validate_plugin_config': ( 'plugin_manager.html#validate_plugin_config',
                                                                                                                                           'cjm_transcription_plugin_system/plugin_manager.py')}}}
